@@ -1,11 +1,12 @@
 /**
- * LIBOMEMO 0.7.1
+ * LIBOMEMO 0.8.0
  */
 
 
 #pragma once
 
 #include <inttypes.h>
+#include <stdbool.h>
 
 #include <glib.h>
 
@@ -427,6 +428,7 @@ int omemo_message_prepare_encryption(char * outgoing_message, uint32_t sender_de
  */
 const uint8_t * omemo_message_get_key(omemo_message * msg_p);
 
+
 /**
  * Gets the length of the symmetric key and appended tag.
  * Again, this only makes sense on an outgoing message.
@@ -451,6 +453,20 @@ size_t omemo_message_get_key_len(omemo_message * msg_p);
  */
 int omemo_message_add_recipient(omemo_message * msg_p, uint32_t device_id, const uint8_t * encrypted_key_p, size_t key_len);
 
+/**
+ * Add the encrypted symmetric key for a specific device id to the message with the prekey attribute.
+ * This notifies the recipient device of the fact that this is the very first message of the session,
+ * which therefore still has to be estalished on its side. 
+ * Only makes sense on outgoing messages.
+ *
+ * @param msg_p Pointer to the message to add to.
+ * @param device_id The recipient device ID.
+ * @param encrypted_key_p The encrypted key data.
+ * @param key_len Length of the encrypted key data.
+ * @return 0 on success, negative on error.
+ */
+int omemo_message_add_recipient_w_prekey(omemo_message * msg_p, uint32_t device_id, const uint8_t * encrypted_key_p, size_t key_len);
+
 /**
  * After all recipients have been added, this function can be used to export the resulting <message> stanza.
  * Also adds a <store> hint.
@@ -534,6 +550,16 @@ char * omemo_message_get_recipient_name_bare(omemo_message * msg_p);
  */
 int omemo_message_get_encrypted_key(omemo_message * msg_p, uint32_t own_device_id, uint8_t ** key_pp, size_t * key_len_p );
 
+/**
+ * Returns whether the key with the speicified device ID is a prekey.
+ * 
+ * @param msg_p Pointer to the message.
+ * @param recipient_device_id  The device ID to check.
+ * @param is_prekey_p Will be set to true if the key is a prekey, false otherwise.
+ * @return int 0 on success, negative on error.
+ */
+int omemo_message_is_encrypted_key_prekey(omemo_message * msg_p, uint32_t recipient_device_id, bool * is_prekey_p);
+
 /**
  * Using the decrypted symmetric key, this method decrypts the payload and exports the original <message> stanza.
  *
